py4ti2: Python bindings for 4ti2
================================

Description
-----------

Py4ti2 provides a Python interface to some of the computations performed by 4ti2.


License
-------

GPL v2 or later


Upstream Contact
----------------

https://github.com/alfsan/Py4ti2
